pub struct ListObjectsV2<'a> { /* private fields */ }
List all objects in the bucket.

If next_continuation_token is Some the response is truncated, and the rest of the list can be retrieved by reusing the ListObjectV2 action but with continuation-token set to the value of next_continuation_token received in the previous response.

Find out more about ListObjectsV2 from the AWS API Reference

Implementations