pub struct ListParts<'a> { /* private fields */ }Expand description
Lists the parts that have been uploaded for a specific multipart upload.
If next_part_number_marker is Some the response is truncated, and the
rest of the list can be retrieved by reusing the ListParts action
but with part_number_marker set to the value of next_part_number_marker
received in the previous response.
Find out more about ListParts from the AWS API Reference
Implementations
sourceimpl<'a> ListParts<'a>
impl<'a> ListParts<'a>
pub fn new(
bucket: &'a Bucket,
credentials: Option<&'a Credentials>,
object: &'a str,
upload_id: &'a str
) -> Self
pub fn set_max_parts(&mut self, max_parts: u16)
pub fn set_part_number_marker(&mut self, part_number_marker: u16)
pub fn parse_response(s: &str) -> Result<ListPartsResponse, DeError>