Struct rusty_s3::actions::UploadPart
source · [−]pub struct UploadPart<'a> { /* private fields */ }Expand description
Upload a part to a previously created multipart upload.
Every part must be between 5 MB and 5 GB in size, except for the last part.
The part must be uploaded via a PUT request, on success the server will
return an ETag header which must be given to
CompleteMultipartUpload in order to
complete the upload.
A maximum of 10,000 parts can be uploaded to a single multipart upload.
The uploaded part will consume storage on S3 until the multipart upload is completed or aborted.
Find out more about UploadPart from the AWS API Reference
Implementations
sourceimpl<'a> UploadPart<'a>
impl<'a> UploadPart<'a>