Module rusty_s3::credentials
source · [−]Expand description
Credentials management types
RotatingCredentials wraps Credentials and gives the ability to
rotate them at any point in the program, keeping all copies of the same
RotatingCredentials in sync with the latest version.
Ec2SecurityCredentialsMetadataResponse parses the response from the
EC2 metadata service,
which provides an endpoint for retrieving credentials using the permissions
for the attached IAM roles.
Structs
S3 credentials
Parser for responses received from the EC2 security-credentials metadata service.
Credentials that can be rotated