Credentials

Struct Credentials 

pub struct Credentials { /* private fields */ }
S3 credentials

Implementations

Source

impl Credentials

pub fn new(key: impl Into<String>, secret: impl Into<String>) -> Self

Construct a new Credentials using the provided key and secret

pub fn new_with_token( key: impl Into<String>, secret: impl Into<String>, token: impl Into<String>, ) -> Self

Construct a new Credentials using the provided key, secret and token

pub fn from_env() -> Option<Self>

Construct a new Credentials using AWS’s default environment variables

Reads the key from the AWS_ACCESS_KEY_ID environment variable and the secret from the AWS_SECRET_ACCESS_KEY environment variable. If AWS_SESSION_TOKEN is set a token is also read. Returns None if either environment variables aren’t set or they aren’t valid utf-8.

pub fn key(&self) -> &str

Get the key of this Credentials

pub fn secret(&self) -> &str

Get the secret of this Credentials

pub fn token(&self) -> Option<&str>

Get the token of this Credentials, if present