pub struct Ec2SecurityCredentialsMetadataResponse { /* private fields */ }
Parser for responses received from the EC2 security-credentials metadata service.

Implementations

Deserialize a JSON response received from the EC2 metadata service.

Parses the credentials from a response received from http://169.254.169.254/latest/meta-data/iam/security-credentials/{name-of-IAM-role}.

Get the key of this Ec2SecurityCredentialsMetadataResponse

Get the secret of this Ec2SecurityCredentialsMetadataResponse

Get the token of this Ec2SecurityCredentialsMetadataResponse

Get the expiration of the credentials of this Ec2SecurityCredentialsMetadataResponse

Convert this Ec2SecurityCredentialsMetadataResponse into Credentials

Update a RotatingCredentials with the credentials of this Ec2SecurityCredentialsMetadataResponse