Struct rusty_s3::credentials::RotatingCredentials
source · [−]pub struct RotatingCredentials { /* private fields */ }Expand description
Credentials that can be rotated
This struct can be cloned and shared around the rest of
the application and will always yield the latest credentials,
by calling RotatingCredentials::get.
Credentials can be updated by calling RotatingCredentials::update.
Implementations