Struct rusty_s3::actions::list_objects_v2::ListObjectsV2
source · [−]pub struct ListObjectsV2<'a> { /* private fields */ }Expand description
List all objects in the bucket.
If next_continuation_token is Some the response is truncated, and the
rest of the list can be retrieved by reusing the ListObjectV2 action
but with continuation-token set to the value of next_continuation_token
received in the previous response.
Find out more about ListObjectsV2 from the AWS API Reference
Implementations
sourceimpl<'a> ListObjectsV2<'a>
impl<'a> ListObjectsV2<'a>
pub fn new(bucket: &'a Bucket, credentials: Option<&'a Credentials>) -> Self
pub fn parse_response(s: &str) -> Result<ListObjectsV2Response, DeError>