pub struct Credentials { /* private fields */ }
S3 credentials

Implementations

Construct a new Credentials using the provided key and secret

Construct a new Credentials using the provided key, secret and token

Construct a new Credentials using AWS’s default environment variables

Reads the key from the AWS_ACCESS_KEY_ID environment variable and the secret from the AWS_SECRET_ACCESS_KEY environment variable. If AWS_SESSION_TOKEN is set a token is also read. Returns None if either environment variables aren’t set or they aren’t valid utf-8.

Get the key of this Credentials

Get the secret of this Credentials

Get the token of this Credentials, if present