Struct rusty_s3::credentials::Credentials
source · [−]pub struct Credentials { /* private fields */ }Expand description
S3 credentials
Implementations
sourceimpl Credentials
impl Credentials
sourcepub fn new(key: impl Into<String>, secret: impl Into<String>) -> Self
pub fn new(key: impl Into<String>, secret: impl Into<String>) -> Self
Construct a new Credentials using the provided key and secret
sourcepub fn new_with_token(
key: impl Into<String>,
secret: impl Into<String>,
token: impl Into<String>
) -> Self
pub fn new_with_token(
key: impl Into<String>,
secret: impl Into<String>,
token: impl Into<String>
) -> Self
Construct a new Credentials using the provided key, secret and token
sourcepub fn from_env() -> Option<Self>
pub fn from_env() -> Option<Self>
Construct a new Credentials using AWS’s default environment variables
Reads the key from the AWS_ACCESS_KEY_ID environment variable and the secret
from the AWS_SECRET_ACCESS_KEY environment variable.
If AWS_SESSION_TOKEN is set a token is also read.
Returns None if either environment variables aren’t set or they aren’t valid utf-8.